@@ -2,9 +2,9 @@ import logging
 import os
 
 from django.db import transaction, IntegrityError
-
 from isc_common import setAttr
 from isc_common.common.functions import delete_dbl_spaces
+
 from kaf_pas.kd.models.document_attributes_view import Document_attributes_view
 
 logger = logging.getLogger(__name__)
@@ -73,11 +73,15 @@ class DocumentManagerExt:
                     STMP_1 = Document_attributes_view.objects.get(document=document, attr_type__code='STMP_1')
                 except Document_attributes_view.DoesNotExist:
                     STMP_1 = None
+                except Document_attributes_view.MultipleObjectsReturned:
+                    STMP_1 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_1')[0]
 
                 try:
                     STMP_2 = Document_attributes_view.objects.get(document=document, attr_type__code='STMP_2')
                 except Document_attributes_view.DoesNotExist:
                     STMP_2 = None
+                except Document_attributes_view.MultipleObjectsReturned:
+                    STMP_2 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_2')[0]
 
                 if STMP_1 != None or STMP_2 != None:
                     props = Item.props.relevant | Item.props.from_spw
@@ -105,7 +109,7 @@ class DocumentManagerExt:
                         if parent_count > 0:
                             break
 
-                    version = None
+                    version = 0
                     if parent_count > 0:
                         version = ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_spw)
 
@@ -250,11 +254,15 @@ class DocumentManagerExt:
                     STMP_1 = Document_attributes_view.objects.get(document=document, attr_type__code='STMP_1')
                 except Document_attributes_view.DoesNotExist:
                     STMP_1 = None
+                except Document_attributes_view.MultipleObjectsReturned:
+                    STMP_1 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_1')[0]
 
                 try:
                     STMP_2 = Document_attributes_view.objects.get(document=document, attr_type__code='STMP_2')
                 except Document_attributes_view.DoesNotExist:
                     STMP_2 = None
+                except Document_attributes_view.MultipleObjectsReturned:
+                    STMP_2 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_2')[0]
 
                 if STMP_1 != None or STMP_2 != None:
                     cnt = Item.objects.filter(
@@ -263,7 +271,7 @@ class DocumentManagerExt:
                         props=Item.props.relevant | Item.props.from_cdw,
                     ).count()
 
-                    version = None
+                    version = 0
                     if cnt != 0:
                         version = ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.relevant | Item.props.from_cdw)
 
@@ -312,8 +320,15 @@ class DocumentManagerExt:
                     STMP_1 = file_name.strip().replace('.pdf', '').replace('.PDF', '')
                     STMP_2 = STMP_1
 
-                STMP_1_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), attr_type=STMP_1_type)
-                STMP_2_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2), attr_type=STMP_2_type)
+                try:
+                    STMP_1_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), attr_type=STMP_1_type)
+                except Document_attributes.MultipleObjectsReturned:
+                    STMP_1_attr = Document_attributes.objects.filter(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), attr_type=STMP_1_type)[0]
+
+                try:
+                    STMP_2_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2), attr_type=STMP_2_type)
+                except Document_attributes.MultipleObjectsReturned:
+                    STMP_2_attr = Document_attributes.objects.filter(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2), attr_type=STMP_2_type)[0]
 
                 cnt = Item.objects.filter(
                     STMP_1__value_str__delete_dbl_spaces=STMP_1,
@@ -321,7 +336,7 @@ class DocumentManagerExt:
                     props=Item.props.relevant | Item.props.from_pdf,
                 ).count()
 
-                version = None
+                version = 0
                 if cnt != 0:
                     version = ItemManager.get_verstion(STMP_1=STMP_1_attr, STMP_2=STMP_2_attr, props=Item.props.from_pdf)
 
